1.1.1.2.1.3. nikola.plugins.misc package — Nikola 8.1.3 documentation

# 1.1.1.2.1.3. nikola.plugins.misc package

Miscellaneous Nikola plugins.

## 1.1.1.2.1.3.1. Submodules

## 1.1.1.2.1.3.2. nikola.plugins.misc.scan_posts module

The default post scanner.

class nikola.plugins.misc.scan_posts.ScanPosts

  Bases: :class:`nikola.plugin_categories.PostScanner`

  Scan posts in the site.

  name = 'scan_posts'
  scan()

    Create list of posts from POSTS and PAGES options.

  supported_extensions()

    Return a list of supported file extensions, or None if such a list isn’t known beforehand.

## 1.1.1.2.1.3.3. nikola.plugins.misc.taxonomies_classifier module

Render the taxonomy overviews, classification pages and feeds.

class nikola.plugins.misc.taxonomies_classifier.TaxonomiesClassifier

  Bases: :class:`nikola.plugin_categories.SignalHandler`

  Classify posts and pages by taxonomies.

  name = 'classify_taxonomies'
  set_site(site)

    Set site, which is a Nikola instance.